Chart Object
============

.. note:: The chart object is currently still lacking a lot of important methods/attributes.

.. note:: Check out the `What's New <http://docs.xlwings.org/whatsnew.html#v0-1-1-june-27-2014>`_ regarding
  the latest changes to the Chart object.
.. module:: xlwings


.. autoclass:: Chart
    :members:

